#!/bin/sh

# remove_bgAppGraphics.sh
# Uninstall Crystal Black graphics for apps
# Script is passed two arguments for app: Name and Path
#
# Created by Leland Scott on 02/09/11.
# Copyright 2011 Musings from Mars. All rights reserved.
# Last updated 3/17/11
# Installs Crystal Black graphics for supported applications, as specified in BGGraphics.plist
# script takes 3 arguments--App name, App path, BG graphics folder
# Updated 9/13 to handle iTunes 10.1/10.4 and Safari SL/Lion
# Updated 5/28/12 for add support for iTunes 6 in CB 1.4
# Updated 12/3/12 to remove support for iTunes, because of incompatibility with itunes 11

# remove_bgAppGraphics.sh -Leap -/Applications/Leap.app

QAPPNAME="$1"
APPNAME=`echo "$QAPPNAME" | sed  's/\"//g'`
APPDIR="$2"
BGGRPHDIR="/Library/Application Support/MarsThemes/CrystalBlack/BGGraphics"
BGDIR="$BGGRPHDIR/$3" # Applications, MenuExtras/Third-Party, PrefPanes...
PSMTABFRAMEPATH="Contents/Frameworks/PSMTabBarControl.framework/Resources"
ORIGZIP="$APPNAME"'_Orig'".zip"
BGZIP="$APPNAME"'_BG'".zip"

OS="SL"
if [ -e /System/Library/Frameworks/CoreMedia.framework ] ; then
	OS="Lion"
fi

echo "Beginning script to restore the original graphics for $APPNAME..."

if [ -d "$APPDIR" ] ; then

#	if [ "$APPNAME" = "iTunes" ] ; then
#		PATHENG="$APPDIR/Contents/Resources/English.lproj"
#		if [ ! -e "$PATHENG/AppConfig.plist" ] && [ ! -e "$PATHENG/MainMenu.nib" ] ; then #introduced in 10.4
#			APPNAME="OldiTunes" # MARK: Added 5/2/12 for cases where user has an older version of iTunes
#		fi
#	fi

	if [ -e "$BGDIR/$APPNAME.zip" ] ; then
		APPDIR="$APPDIR/Contents/Resources"
		cp "$BGDIR/$APPNAME.zip" "$APPDIR/"
		cd "$APPDIR/"
		unzip -o "$APPNAME.zip"
		rm "$APPNAME.zip"
		unzip -o "$ORIGZIP"
		rm "$ORIGZIP"
		rm "$BGZIP"

		# Check for any old CCI zip files and delete
		if [ -e "Orig.zip" ] ; then # These two were used for menu extras in an earlier version of CCI
			rm "Orig.zip"
		fi
		if [ -e "CCI.zip" ] ; then
			rm "CCI.zip"
		fi
		if [ -e "$i"'_Orig'".zip" ] ; then
			rm "$i"'_Orig'".zip"
		fi
		if [ -e "$i"'_CCI'".zip" ] ; then
			rm "$i"'_CCI'".zip"
		fi

		if [ -d "__MACOSX" ] ; then # MARK: 4/12/12: Adding this routine to all from CCI 2.6
			/bin/rm -R "__MACOSX"
		fi
		
		if [ "$APPNAME" = "Mail" ] || [ "$APPNAME" = "Preview" ] ; then
			chown root:wheel *.tiff
			chown root:wheel *.png
		fi
		
		#special cases
		#VectorDesigner
		if [ "$APPNAME" = "VectorDesigner" ] ; then
			if [ -e "background.tif" ] ; then
				rm ../Frameworks/TSCore.framework/Resources/background.tif
				mv "background.tif" ../Frameworks/TSCore.framework/Resources/
			fi
		#iTunes
#		elif [ "$APPNAME" = "iTunes" ] ; then
#			if [ -e "TextStyles.plist" ] ; then
#				rm "English.lproj/TextStyles.plist"
#				mv "TextStyles.plist" "English.lproj/"
#			fi
		fi
	# Installing PSMTabBarControl graphics
	elif [ "$APPNAME" = "Evernote" ] ; then
		echo "Installing PSMTabBarControl graphics for Evernote..."
		cp "$BGDIR/Frameworks/PSMTabBarControl.zip" "$APPDIR/$PSMTABFRAMEPATH/"
		cd "$APPDIR/$PSMTABFRAMEPATH/"
		unzip -o "PSMTabBarControl.zip"
		rm "PSMTabBarControl_BG.zip"
		unzip -o "PSMTabBarControl_Orig.zip"
		rm "PSMTabBarControl.zip"
	else
		echo "Crystal Black zip file for $APPNAME not found!"
		continue
	fi
	
else
	echo "$APPNAME application not found at path $APPDIR"
fi

exit 0

