#!/bin/sh

# remove_bgAppleExtras.sh
#
# Created by Leland Scott on 06/16/10.
# Copyright 2010 Musings from Mars. All rights reserved.
# Last updated 3/17/11
# Restores the default icons for Apple statusbar extras:
#	Volume
#	User
#	UniversalAccess
#	TimeMachine
#	Sync
#	Spotlight
#	Spaces
#	Script
#	Ink
#	iChat
#	Eject
#	Displays
#	Bluetooth
#	Battery
#   WLAN (Lion for Airport)
#	Updated 8/22/10 to add menu extra for Keychain, which isn't in the CoreServices folder


ORIGZIP="_Orig.zip"
BGZIP="_BG.zip"
OS="SL"
if [ -e /System/Library/PrivateFrameworks/ShareKit.framework ] ; then
	OS="ML"
elif [ -e /System/Library/Frameworks/CoreMedia.framework ] ; then
	OS="Lion"
fi

echo "Beginning script to restore the black Apple statusbar icons..."

IFS=":"
LIST="Volume:User:UniversalAccess:TimeMachine:Sync:Spotlight:Spaces:Ink:iChat:Eject:Displays:Bluetooth:Battery:Airport:Keychain:Script:VPN:WLAN:Notifications" 
SYSDIR="/System/Library/CoreServices"
BGDIR="/Library/Application Support/MarsThemes/CrystalBlack/BGGraphics/MenuExtras/Apple"

for i in $LIST ; do

	EXTDIR=""
	SUBDIR="Contents/Resources"
	APPDIR=""

	STATE1="Restoring original menu extra for $i."
	STATE2="Original $i Icons are missing."
	STATE3="Couldn't find the system folder for $i!"
	
	echo "$STATE1"
	
	if [ $i = "Spotlight" ] ; then
		EXTDIR="$SYSDIR/Search.bundle"
	elif [ $i = "Keychain" ] ; then
		EXTDIR="/Applications/Utilities/Keychain Access.app/Contents/Resources/Keychain.menu"
	elif [ $i = "Script" ] ; then
		EXTDIR="$SYSDIR/Menu Extras/Script Menu.menu"
	elif [ $i = "WLAN" ] ; then
		if [ $OS = "Lion" ] || [ $OS = "ML" ] ; then
			EXTDIR="/System/Library/PrivateFrameworks/CoreWLANKit.framework/Resources"
			SUBDIR=""
		fi
	elif [ $i = "Notifications" ] ; then # Added for Mountain Lion
		EXTDIR="$SYSDIR/NotificationCenter.app"
	else
		EXTDIR="$SYSDIR/Menu Extras/$i.menu"
	fi
	
	if [ ! -d "$EXTDIR" ] ; then
		echo "$STATE3"
		continue
	fi

	APPDIR="$EXTDIR/$SUBDIR"

	echo "$APPDIR"
	
	if [ -e "$BGDIR/$i.zip" ] ; then
		cp "$BGDIR/$i.zip" "$APPDIR/$i.zip"
		cd "$APPDIR"
		unzip -o "$i.zip"
		rm "$i.zip"
		unzip -o "$i$ORIGZIP"
		rm "$i$ORIGZIP"
		rm "$i$BGZIP"
	else
		echo "$STATE2"
		continue
	fi

done

exit 0


