#!/bin/sh

# remove_bgSystemGraphics.sh
#
# Created by Leland Scott on 02/10/11.
# Copyright 2011 Musings from Mars. All rights reserved.
# Last updated 3/17/11
# Last updated 5/23/12 for CB 1.4
# Installs or uninstalls system graphics for:
#	CoreServices
#		CoreTypes.bundle
#		loginwindow.bundle -> named login
#	Frameworks
#		Quartz/ImageKit
#		Automator
#		PreferencePanes
#		WebKitInspector
#		AddressBook
#	PrivateFrameworks
#		iLifeMediaBrowser
#	Developer
#		DevToolsInterface
#		DocSetViewing
#	Other
#		Finder
#		CharacterPalette
#		loginwindow

# remove_bgSystemGraphics -groupname for restore

GROUP="$1" # CoreServices, Frameworks, ...
ORIGZIP="_Orig.zip"
BGZIP="_BG.zip"

BGGRAPHICS="/Library/Application Support/MarsThemes/CrystalBlack/BGGraphics"
BGDIR="$BGGRAPHICS/System/$GROUP"
SYSDIR="/System/Library/$GROUP"
SUBDIR="Contents/Resources"
PARENTDIR=""
IFS=":"
FULLDIR=""
EXT="framework"

echo "Beginning script to restore the Apple system graphics..."

# CoreServices graphics
if [ $GROUP = "CoreServices" ] ; then
	LIST="CoreTypes:login" 
	EXT="bundle"

elif [ $GROUP = "Frameworks" ] ; then
	LIST="ImageKit:Automator:PreferencePanes:WebKitInspector:AddressBook"
	SUBDIR="Resources" 

elif [ $GROUP = "PrivateFrameworks" ] ; then
	LIST="iLifeMediaBrowser" 
	SUBDIR="Resources" 

#elif [ $GROUP = "LoginPlugins" ] ; then
#
#	LIST="FSDisconnect" 
#	EXT="loginPlugins"

elif [ $GROUP = "Developer" ] ; then
	LIST="DevToolsInterface:DocSetViewing" 
	SYSDIR="/Developer/Library/PrivateFrameworks"
	SUBDIR="Resources"

elif [ $GROUP = "Other" ] ; then
	LIST="Finder:CharacterPalette:loginwindow" 
	SYSDIR="/System/Library/CoreServices"
	EXT="app"
fi


for i in $LIST ; do
	STATE1="Restoring original system graphics for $i."
	STATE2="Original $i system graphics are missing."
	STATE3="Couldn't find the system folder for $i!"
	
	echo "$STATE1"
	
	if [ $i = "login" ] ; then
		FULLDIR="$SYSDIR/SecurityAgentPlugins/loginwindow.$EXT/$SUBDIR"
	elif [ $i = "ImageKit" ] ; then
		FULLDIR="$SYSDIR/Quartz.framework/Frameworks/$i.$EXT/$SUBDIR"
	elif [ $i = "DevToolsInterface" ] ; then
		FULLDIR="$SYSDIR/$i.$EXT/$SUBDIR/English.lproj"
	elif [ $i = "WebKitInspector" ] ; then
		FULLDIR="$SYSDIR/WebKit.framework/Versions/A/Frameworks/WebCore.framework/Versions/A/Resources/inspector/Images"
	elif [ $i = "CharacterPalette" ] ; then
		FULLDIR="/System/Library/Input Methods/$i.$EXT/$SUBDIR"
	else
		FULLDIR="$SYSDIR/$i.$EXT/$SUBDIR"
	fi
	
	if [ ! -d "$FULLDIR" ] ; then
		echo "$STATE3"
		continue
	fi

	echo "$FULLDIR"
	
	if [ -e "$BGDIR/$i.zip" ] ; then
		cp "$BGDIR/$i.zip" "$FULLDIR/$i.zip"
		cd "$FULLDIR"
		unzip -o "$i.zip"
		rm "$i.zip"
		unzip -o "$i$ORIGZIP"
		rm "$i$ORIGZIP"
		rm "$i$BGZIP"
		# Check for any old CCI zip files and delete
		if [ -e "$i"'_Orig'".zip" ] ; then
			rm "$i"'_Orig'".zip"
		fi
		if [ -e "$i"'_CCI'".zip" ] ; then
			rm "$i"'_CCI'".zip"
		fi
		
		if [ $i = "WebKitInspector" ] ; then
			# must first remove the files to be overwritten.
			rm ../inspector.css 
			rm ../inspectorSyntaxHighlight.css
			rm ../textViewer.css
			mv *.css ../  # move css files to inspector folder; by default, files unzipped in images subfolder
		fi

		if [ "$i" = "login" ] || [ "$i" = "CoreTypes" ] ; then # MARK: 6/18/12: Added after going through repair log in Console
			chown root:wheel *.tif
			chown root:wheel *.icns
		fi

	else
		echo "$STATE2"
		continue
	fi
	
done


exit 0



